==> idyntree-2.0.3.dev31.tar.gz: idyntree-2.0.3.dev31/bindings/matlab/autogenerated/+iDynTree/TransformDerivative.m <==
classdef TransformDerivative < SwigRef
  methods
    function this = swig_this(self)
      this = iDynTreeMEX(3, self);
    end
    function self = TransformDerivative(varargin)
      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
        if ~isnull(varargin{1})
          self.swigPtr = varargin{1}.swigPtr;
        end
      else
        tmp = iDynTreeMEX(684, varargin{:});
        self.swigPtr = tmp.swigPtr;
        tmp.SwigClear();
      end
    end
    function delete(self)
      if self.swigPtr
        iDynTreeMEX(685, self);
        self.SwigClear();
      end
    end
    function varargout = getRotationDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(686, self, varargin{:});
    end
    function varargout = getPositionDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(687, self, varargin{:});
    end
    function varargout = setRotationDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(688, self, varargin{:});
    end
    function varargout = setPositionDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(689, self, varargin{:});
    end
    function varargout = asHomogeneousTransformDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(691, self, varargin{:});
    end
    function varargout = asAdjointTransformDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(692, self, varargin{:});
    end
    function varargout = asAdjointTransformWrenchDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(693, self, varargin{:});
    end
    function varargout = mtimes(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(694, self, varargin{:});
    end
    function varargout = derivativeOfInverse(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(695, self, varargin{:});
    end
    function varargout = transform(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(696, self, varargin{:});
    end
  end
  methods(Static)
    function varargout = Zero(varargin)
     [varargout{1:nargout}] = iDynTreeMEX(690, varargin{:});
    end
  end
end

==> idyntree-6.0.1.dev3.tar.gz: idyntree-6.0.1.dev3/bindings/matlab/autogenerated/+iDynTree/TransformDerivative.m <==
classdef TransformDerivative < iDynTreeSwigRef
  methods
    function this = swig_this(self)
      this = iDynTreeMEX(3, self);
    end
    function self = TransformDerivative(varargin)
      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
        if ~isnull(varargin{1})
          self.swigPtr = varargin{1}.swigPtr;
        end
      else
        tmp = iDynTreeMEX(684, varargin{:});
        self.swigPtr = tmp.swigPtr;
        tmp.SwigClear();
      end
    end
    function delete(self)
      if self.swigPtr
        iDynTreeMEX(685, self);
        self.SwigClear();
      end
    end
    function varargout = getRotationDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(686, self, varargin{:});
    end
    function varargout = getPositionDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(687, self, varargin{:});
    end
    function varargout = setRotationDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(688, self, varargin{:});
    end
    function varargout = setPositionDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(689, self, varargin{:});
    end
    function varargout = asHomogeneousTransformDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(691, self, varargin{:});
    end
    function varargout = asAdjointTransformDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(692, self, varargin{:});
    end
    function varargout = asAdjointTransformWrenchDerivative(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(693, self, varargin{:});
    end
    function varargout = mtimes(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(694, self, varargin{:});
    end
    function varargout = derivativeOfInverse(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(695, self, varargin{:});
    end
    function varargout = transform(self,varargin)
      [varargout{1:nargout}] = iDynTreeMEX(696, self, varargin{:});
    end
  end
  methods(Static)
    function varargout = Zero(varargin)
     [varargout{1:nargout}] = iDynTreeMEX(690, varargin{:});
    end
  end
end
